@@ -15,19 +15,16 @@ from .resolve import identify
 # Path definitions required throughout the code
 PATH_CACHE = Path.home() / ".cache/rocks"
 PATH_INDEX = PATH_CACHE / "index"
-PATH_META = {
-    "description": PATH_CACHE / "ssoCard_description.json",
-    "units": PATH_CACHE / "ssoCard_units.json",
-}
+PATH_MAPPING = PATH_CACHE / "mapping_aster-astorb.json"
 
 # Dict to hold the asteroid name-number indices at runtime
 INDEX = {}
 
 # ------
 # Welcome to rocks
-__version__ = "1.4.22"
+__version__ = "1.4.24"
 
-GREETING = fr"""
+GREETING = rf"""
                 _
                | |
  _ __ ___   ___| | _____
