@@ -82,16 +82,13 @@ def info(id_):
 
 
 @cli_rocks.command()
-@click.option("--units", "-u", is_flag=True, help="Echo the parameter units.")
-def parameters(units):
+def parameters():
     """Print the ssoCard structure and its description."""
 
-    which = "description" if not units else "units"
+    if not rocks.PATH_MAPPING.is_file():
+        rocks.utils.retrieve_mappings_from_ssodnet()
 
-    if not rocks.PATH_META[which].is_file():
-        rocks.utils.retrieve_json_from_ssodnet(which)
-
-    with open(rocks.PATH_META[which], "r") as file_:
+    with open(rocks.PATH_MAPPING, "r") as file_:
         DESC = json.load(file_)
 
     rich.print(DESC)
@@ -137,7 +134,9 @@ def status():
     # Echo update recommendations
     latest_rocks = rocks.utils.retrieve_rocks_version()
 
-    if latest_rocks and latest_rocks != rocks.__version__:
+    if latest_rocks and tuple(map(int, latest_rocks.split("."))) > tuple(
+        map(int, rocks.__version__.split("."))
+    ):
         rich.print(
             f"[red]The running [green]rocks[/green] version ({rocks.__version__}) is behind the "
             f"latest version ({latest_rocks}). The ssoCard structure might have changed.[/red]"
@@ -166,8 +165,7 @@ def status():
         elif decision == "2":
 
             # Update metadata
-            for meta in rocks.PATH_META.keys():
-                rocks.utils.retrieve_json_from_ssodnet(meta)
+            rocks.utils.retrieve_mappings_from_ssodnet()
 
             # Update the cached data
             ids = [ssodnet_id for ssodnet_id in cached_cards]
@@ -218,6 +216,17 @@ def echo():
     else:
         plot = False
 
+    # Verbose output?
+    for arg in ["-v", "--verbose"]:
+
+        if arg in sys.argv:
+            sys.argv.remove(arg)
+
+            verbose = True
+            break
+    else:
+        verbose = False
+
     # Are there enough arguments to continue?
     if len(sys.argv) == 2:
         print(f"\nUnknown command '{sys.argv[-1]}'.\n")
@@ -245,7 +254,7 @@ def echo():
     ]
 
     # And let's go
-    rock = rocks.Rock(id_, datacloud=datacloud)
+    rock = rocks.Rock(id_, datacloud=datacloud, suppress_errors=not verbose)
 
     # Identifier could not be resolved
     if not rock.id_:
